Unicode-EastAsianWidth-JS
*************************

Counting the unicode characters based `Unicode East Asian Width database`_ for JavaScript.
It includes some tools for dealing with characters.

.. _`Unicode East Asian Width database`: http://www.unicode.org/Public/UNIDATA/EastAsianWidth.txt

js.unicode_eastasianwidth |Build Status|_
-----------------------------------------

.. |Build Status| image:: https://travis-ci.org/MiCHiLU/Unicode-EastAsianWidth-JS.png?branch=python
.. _`Build Status`: http://travis-ci.org/MiCHiLU/Unicode-EastAsianWidth-JS

Introduction
============

This library packages `Unicode-EastAsianWidth-JS`_ for `fanstatic`_.

.. _`fanstatic`: http://fanstatic.org
.. _`Unicode-EastAsianWidth-JS`: https://github.com/MiCHiLU/Unicode-EastAsianWidth-JS

This requires integration between your web framework and ``fanstatic``,
and making sure that the original resources (shipped in the ``resources``
directory in ``js.unicode_eastasianwidth``) are published to some URL.
